#!/bin/bash

#author				: hennes (jm@rapidrabbit.de)
#last changed		: 01-august-2007

#package			: penguin-command
#homepgae			: http://user.cs.tu-berlin.de/~karlb/penguin-command/
#source location	: http://prdownloads.sourceforge.net/penguin-command/penguin-command-1.6.11.tar.gz
#dependencies		: coreutils,directfb,expat,fontconfig,freetype,gcc,gcc-g++,libdrm,libjpeg,libpng,libtiff,mesa,ncurses,perl,sdl,sysfsutils,xorg,xterm,zlib

# ----- credentials
softname="penguin-command"
softversion="1.6.11"
srcurl="http://prdownloads.sourceforge.net/penguin-command/penguin-command-1.6.11.tar.gz"
arch=i486
cpu=i686
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 0
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/16x16/apps
mkdir -p $dest/usr/share/icons/hicolor/22x22/apps
mkdir -p $dest/usr/share/icons/hicolor/24x24/apps
mkdir -p $dest/usr/share/icons/hicolor/32x32/apps
mkdir -p $dest/usr/share/icons/hicolor/36x36/apps
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/man/man6
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
               |-----handy-ruler------------------------------------------------------|
penguin-command: penguin-command (missile command clone)
penguin-command:
penguin-command: This is a clone of the classic "Missile Command" Game, but it has
penguin-command: better graphics and music. The gameplay has only been slightly
penguin-command: modified.
penguin-command:
penguin-command:
penguin-command:
penguin-command:
penguin-command:
penguin-command:
EOF

# ----- extract source-archive
srcdir=$softname-$softversion
rm -rf $srcdir
if [ -f $softname-$softversion.tar.gz ]; then
   echo "looking for source-file .. found"
else
   echo "looking for source-file .. none found"
   wget -c $srcurl
fi
tar -zxvf $softname-$softversion.tar.gz
cd $srcdir

# ----- create package-dependent directories
mkdir -p $dest/usr/doc/$srcdir

# ----- set target-permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- configure
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
	--prefix=$prefix \
	--disable-debug
	
# ----- make
make $numjobs
	
# ----- make install
make install DESTDIR=$dest

# ----- add default-files
cp -a \
	AUTHORS COPYING ChangeLog INSTALL NEWS README \
	$dest/usr/doc/$srcdir

# ----- treat icon-files
cd $builddir
tar -jxvf icons.tar.bz2 --directory=$builddir
cp icon-penguin-command-16.png $dest/usr/share/icons/hicolor/16x16/apps/penguin-command.png
cp icon-penguin-command-22.png $dest/usr/share/icons/hicolor/22x22/apps/penguin-command.png
cp icon-penguin-command-24.png $dest/usr/share/icons/hicolor/24x24/apps/penguin-command.png
cp icon-penguin-command-32.png $dest/usr/share/icons/hicolor/32x32/apps/penguin-command.png
cp icon-penguin-command-36.png $dest/usr/share/icons/hicolor/36x36/apps/penguin-command.png
cp icon-penguin-command-48.png $dest/usr/share/icons/hicolor/48x48/apps/penguin-command.png
cp icons.tar.bz2 $destsrc
rm -f $dest/usr/share/penguin-command/gfx/icon.xpm

# ----- make .desktop-file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Penguin Command
Comment=Arcade Shooting Game
Exec=penguin-command
Icon=penguin-command
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
Encoding=UTF-8
EOF

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

# ----- get-source-script
cat << EOF > "$destsrc/getsrc.sh"
wget -c $srcurl
EOF

chmod a+x "$destsrc/getsrc.sh"

# ----- post-build processing
cd $dest
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null

mv $dest/usr/share/man/man6/*.* $dest/usr/man/man6
rm -rf $dest/usr/share/man

for mandir in $(find . -name man -type d) ; do
	if [ -d $mandir ]; then
		( cd $mandir
		  find . -type f -name "*.?" -exec gzip -9 {} \;
		)
	fi
done
	
# ----- packaging
chown -R root.root $dest/usr/bin
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5
cat << "EOF" > $builddir/$package.dep
coreutils,directfb,expat,fontconfig,freetype,gcc,gcc-g++,libdrm,libjpeg,libpng,libtiff,mesa,ncurses,perl,sdl,sysfsutils,xorg,xterm,zlib
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
fi
